@@ -6,12 +6,12 @@
 //! > **Command Line Argument Parser for Rust**
 //!
 //! Quick Links:
-//! - Derive [tutorial][_derive::_tutorial::chapter_0] and [reference][_derive]
-//! - Builder [tutorial][_tutorial::chapter_0] and [reference](index.html)
+//! - Derive [tutorial][_derive::_tutorial] and [reference][_derive]
+//! - Builder [tutorial][_tutorial] and [reference][Command]
 //! - [Cookbook][_cookbook]
 //! - [FAQ][_faq]
 //! - [Discussions](https://github.com/clap-rs/clap/discussions)
-//! - [CHANGELOG](https://github.com/clap-rs/clap/blob/v4.5.22/CHANGELOG.md) (includes major version migration
+//! - [CHANGELOG](https://github.com/clap-rs/clap/blob/v4.5.42/CHANGELOG.md) (includes major version migration
 //!   guides)
 //!
 //! ## Aspirations
@@ -67,7 +67,7 @@
 //! - [clio](https://crates.io/crates/clio) for reading/writing to files specified as arguments
 //! - [clap-verbosity-flag](https://crates.io/crates/clap-verbosity-flag)
 //! - [clap-cargo](https://crates.io/crates/clap-cargo)
-//! - [concolor-clap](https://crates.io/crates/concolor-clap)
+//! - [colorchoice-clap](https://crates.io/crates/colorchoice-clap)
 //!
 //! Testing
 //! - [`trycmd`](https://crates.io/crates/trycmd):  Bulk snapshot testing
@@ -100,3 +100,7 @@ pub mod _faq;
 pub mod _features;
 #[cfg(feature = "unstable-doc")]
 pub mod _tutorial;
+
+#[doc = include_str!("../README.md")]
+#[cfg(doctest)]
+pub struct ReadmeDoctests;
